%----------------------------------------------------------
% EEGStarlab Toolbox
% (C) Starlab S.L.
%----------------------------------------------------------
% Computes the power spectral density (PSD) of a time series
%----------------------------------------------------------
%Inputs
% signal: time series in units
% fs: Sampling rate in Hz
%----------------------------------------------------------
%Outputs
% psd: Power spectral density of the time series in units^2/Hz  
% freq: Frequency steps of the PSD
%----------------------------------------------------------
%No Dependencies
%----------------------------------------------------------
% Version   Date        Author  Changes 
% v1        13/05/13    DIS     Initial Edition     
%----------------------------------------------------------
% EX.
%  t=0:0.01:2;
%  signal = 5 * sin(2*pi*t*20) + 10* sin(2*pi*t*10) + randn(1, length(t));
%  [f, Y] = StarPSD(signal, 100);
%  figure; plot(f,Y); xlabel('Frequency (Hz)'); ylabel('Units^2 / Hz');
%--------------------------------------------------------------


function [freq, psd] = StarPSD(signal, Fs)


N = length(signal);
NFFT = 2^nextpow2(N); 
xdft = fft(signal,NFFT);
xdft = xdft(1:NFFT/2+1);
psd = (1/(Fs*length(signal))).*abs(xdft).^2;
psd(2:end-1) = 2*psd(2:end-1);
freq =Fs/2*linspace(0,1,NFFT/2+1);
 